==> jetty9_9.2.23.orig.tar.xz: jetty9-9.2.23/examples/embedded/src/main/java/org/eclipse/jetty/embedded/ExampleServerXml.java <==
//
//  ========================================================================
//  Copyright (c) 1995-2017 Mort Bay Consulting Pty. Ltd.
//  ------------------------------------------------------------------------
//  All rights reserved. This program and the accompanying materials
//  are made available under the terms of the Eclipse Public License v1.0
//  and Apache License v2.0 which accompanies this distribution.
//
//      The Eclipse Public License is available at
//      http://www.eclipse.org/legal/epl-v10.html
//
//      The Apache License v2.0 is available at
//      http://www.opensource.org/licenses/apache2.0.php
//
//  You may elect to redistribute this code under either of these licenses.
//  ========================================================================
//

package org.eclipse.jetty.embedded;

import org.eclipse.jetty.util.resource.Resource;
import org.eclipse.jetty.xml.XmlConfiguration;

/**
 * Configures and Starts a Jetty server from an XML declaration.
 * <p>
 * See <a href="https://raw.githubusercontent.com/eclipse/jetty.project/master/examples/embedded/src/main/resources/exampleserver.xml">exampleserver.xml</a>
 * </p>
 */
public class ExampleServerXml
{
    public static void main( String[] args ) throws Exception
    {
        // Find Jetty XML (in classpath) that configures and starts Server.
        Resource serverXml = Resource.newSystemResource("exampleserver.xml");
        XmlConfiguration.main(serverXml.getFile().getAbsolutePath());
    }
}

==> jetty9_9.2.30.orig.tar.xz: jetty9-9.2.30/examples/embedded/src/main/java/org/eclipse/jetty/embedded/ExampleServerXml.java <==
//
//  ========================================================================
//  Copyright (c) 1995-2020 Mort Bay Consulting Pty Ltd and others.
//  ------------------------------------------------------------------------
//  All rights reserved. This program and the accompanying materials
//  are made available under the terms of the Eclipse Public License v1.0
//  and Apache License v2.0 which accompanies this distribution.
//
//      The Eclipse Public License is available at
//      http://www.eclipse.org/legal/epl-v10.html
//
//      The Apache License v2.0 is available at
//      http://www.opensource.org/licenses/apache2.0.php
//
//  You may elect to redistribute this code under either of these licenses.
//  ========================================================================
//

package org.eclipse.jetty.embedded;

import org.eclipse.jetty.util.resource.Resource;
import org.eclipse.jetty.xml.XmlConfiguration;

/**
 * Configures and Starts a Jetty server from an XML declaration.
 * <p>
 * See <a href="https://github.com/eclipse/jetty.project/raw/jetty-9.2.x/examples/embedded/src/main/resources/exampleserver.xml">exampleserver.xml</a>
 * </p>
 */
public class ExampleServerXml
{
    public static void main( String[] args ) throws Exception
    {
        // Find Jetty XML (in classpath) that configures and starts Server.
        Resource serverXml = Resource.newSystemResource("exampleserver.xml");
        XmlConfiguration.main(serverXml.getFile().getAbsolutePath());
    }
}
